==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/template/RoleFollowerArchiveItem.java <==
package cc.thonly.reverie_dreams.item.template;

import cc.thonly.reverie_dreams.component.ModDataComponentTypes;
import cc.thonly.reverie_dreams.component.RoleFollowerArchive;
import java.util.function.Consumer;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3417;

public class RoleFollowerArchiveItem extends class_1792 {
    public static final class_3414 SOUND = class_3417.field_15126;

    public RoleFollowerArchiveItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        class_1937 contextWorld = context.method_8045();
        class_1657 player = context.method_8036();
        if (!contextWorld.method_8608() && contextWorld instanceof class_3218 world && player != null) {
            class_1799 stack = context.method_8041();
            RoleFollowerArchive followerArchive = stack.method_58694(ModDataComponentTypes.ROLE_FOLLOWER_ARCHIVE);
            if (followerArchive == null) {
                return class_1269.field_5811;
            }
            boolean canRespawn = stack.method_58695(ModDataComponentTypes.ROLE_CAN_RESPAWN, false);
            if (!canRespawn) {
                return class_1269.field_5811;
            }
            followerArchive.respawn(world, context.method_8037().method_10084(), world.method_30349());
            world.method_43128(null, player.method_23317(), player.method_23318(), player.method_23321(), SOUND, player.method_5634(), 2.0f, 1.0f);
            stack.method_57008(1, player);
            player.method_6104(context.method_20287());
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

//    @Override
//    public void appendTooltip(ItemStack stack, TooltipContext context, TooltipDisplayComponent displayComponent, Consumer<Text> textConsumer, TooltipType type) {
//        super.appendTooltip(stack, context, displayComponent, textConsumer, type);
////        RoleFollowerArchive archive = stack.get(ModDataComponentTypes.ROLE_FOLLOWER_ARCHIVE);
////        if (archive != null) {
////            String name = archive.getNameJson();
////            MutableText main = Text.empty();
////            Text mutableText = TextUtil.decode(name).orElse(Text.empty());
////            main.append("Name: ");
////            main.append(mutableText);
////            textConsumer.accept(main);
////        }
//    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/template/RoleFollowerArchiveItem.java <==
package cc.thonly.reverie_dreams.item.template;

import cc.thonly.reverie_dreams.registry.content.component.RDDataComponentTypes;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import cc.thonly.reverie_dreams.component.RoleFollowerArchive;

public class RoleFollowerArchiveItem extends class_1792 {
    public static final class_3414 SOUND = class_3417.field_15126;

    public RoleFollowerArchiveItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        class_1937 contextWorld = context.method_8045();
        class_1657 player = context.method_8036();
        if (!contextWorld.method_8608() && contextWorld instanceof class_3218 world && player != null) {
            class_1799 stack = context.method_8041();
            RoleFollowerArchive followerArchive = stack.method_58694(RDDataComponentTypes.ROLE_FOLLOWER_ARCHIVE);
            if (followerArchive == null) {
                return class_1269.field_5811;
            }
            boolean canRespawn = stack.method_58695(RDDataComponentTypes.ROLE_CAN_RESPAWN, false);
            if (!canRespawn) {
                return class_1269.field_5811;
            }
            followerArchive.respawn(world, context.method_8037().method_10084(), world.method_30349());
            world.method_43128(null, player.method_23317(), player.method_23318(), player.method_23321(), SOUND, player.method_5634(), 2.0f, 1.0f);
            stack.method_57008(1, player);
            player.method_6104(context.method_20287());
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

}
